pub struct Migrations<'a> { /* private fields */ }Expand description
Manages the application of migrations.
Implementations
Sourceimpl<'a> Migrations<'a>
impl<'a> Migrations<'a>
pub const fn new(migrations: &'a [Migration<'a>]) -> Self
Sourcepub async fn to_latest(
&self,
conn: &mut Connection,
) -> Result<usize, (usize, MigrationError)>
pub async fn to_latest( &self, conn: &mut Connection, ) -> Result<usize, (usize, MigrationError)>
Applies all pending migrations to bring the database to the latest version. Each migration is applied in its own transaction. Returns the number of applied migrations. Uses the turso/sqlite table user_version to track the current version.
Sourcepub async fn run_all_in_memory(&self) -> Result<Connection, MigrationError>
pub async fn run_all_in_memory(&self) -> Result<Connection, MigrationError>
Helper function to validate migrations by applying them to an in-memory database. Returns the connection to the in-memory database if successful.